@@ -1,3 +1,4 @@
+import os
 import sys
 import asyncio
 import logging
@@ -19,7 +20,7 @@ default_upload_resources = True
 default_save_internal_metadata = True
 
 
-async def main():
+async def main(section_name):
     # read config
     # TODO: move to another funcion
     # TODO: made a config object (maybe pydantic) and pass the object
@@ -42,12 +43,6 @@ async def main():
         logging.error("Missing 'section' field in config!")
         sys.exist(1)
 
-    # TODO: read the toml section from cli
-    # for now read the first one
-    for section in sections_config:
-        section_name = section
-        break
-
     if section_name not in sections_config:
         logging.error(f"Section {section_name} not in config!")
         sys.exist(1)
@@ -142,7 +137,16 @@ async def main():
 
 
 def run():
+    args = sys.argv[1:]
+    env_section_name = os.environ.get("SECTION_NAME")
+
+    if not args and not env_section_name:
+        logging.error("You need to pass the section_name like: 'dpa some_section_name'")
+        sys.exit(1)
+    elif not args:
+        section_name = env_section_name
+    else:
+        section_name = args[0]
+
     logging.basicConfig(encoding="utf-8", level=logging.INFO)
-    print("start")
-    asyncio.run(main())
-    print("end")
+    asyncio.run(main(section_name=section_name))
